======
Metron
======

.. image:: https://img.shields.io/travis/pinax/metron.svg
    :target: https://travis-ci.org/pinax/metron

.. image:: https://img.shields.io/coveralls/pinax/metron.svg
    :target: https://coveralls.io/r/pinax/metron

.. image:: https://img.shields.io/pypi/dm/metron.svg
    :target:  https://pypi.python.org/pypi/metron/

.. image:: https://img.shields.io/pypi/v/metron.svg
    :target:  https://pypi.python.org/pypi/metron/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/metron/


Current analytics services supported:

* Google Analytics
* Mixpanel
* gaug.es
* Google AdWords Conversion Tracking


Documentation
-------------

Documentation can be found online at http://metron.readthedocs.org/
